#
# spec file for package mypy
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mypy
Version:        0.620
Release:        3.8
Summary:        Optional static typing for Python
License:        MIT
Group:          Development/Languages/Python
URL:            http://www.mypy-lang.org/
Source:         https://files.pythonhosted.org/packages/source/m/mypy/mypy-%{version}.tar.gz
Patch0:         0001-Look-for-typeshed-in-usr-share.patch
Patch1:         0002-Canonicalize-bin_dir-when-looking-for-data_dir.patch
Patch2:         0003-Pass-executable-path-into-main-when-running-installe.patch
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-setuptools
Requires:       python3-mypy_extensions >= 0.4.0
Requires:       python3-psutil >= 5.4.0
Requires:       python3-typed-ast >= 1.1.0
BuildArch:      noarch
Provides:       python3-mypy = %{version}
Obsoletes:      python3-mypy < %{version}
# SECTION docs
BuildRequires:  python3-Sphinx >= 1.4.4
BuildRequires:  python3-sphinx_rtd_theme >= 0.1.9
# /SECTION

%description
Mypy is an optional static type checker for Python that aims to
combine the benefits of both dynamic (or "duck") typing as well as
static typing.

Mypy type checks standard Python programs. It can catch many
programming errors by analyzing programs without having to run them.
There is basically no runtime overhead when run using any Python VM.
Mypy's type system features type inference, gradual typing, generics
and union types.

%prep
%autosetup -n mypy-%{version} -p1

%build
%python3_build
pushd docs
make %{?_smp_mflags} html
rm build/html/.buildinfo
popd

%install
%python3_install
%fdupes %{buildroot}

%files
%doc docs/README.md docs/build/html/
%license LICENSE
%{python3_sitelib}/*
%{_bindir}/dmypy
%{_bindir}/mypy
%{_bindir}/stubgen
%{_libexecdir}/mypy

%changelog
* Tue Aug 28 2018 mimi.vx@gmail.com
- desinglespec - is app and only for python3
- add RH patchset:
  0001-Look-for-typeshed-in-usr-share.patch
  0002-Canonicalize-bin_dir-when-looking-for-data_dir.patch
  0003-Pass-executable-path-into-main-when-running-installe.patch
* Mon Aug 27 2018 mimi.vx@gmail.com
- update to 0.620
- fix install deps
  * support for dataclasses
  * better support for PEP 561
  * adds support for dmypy run and a host of other small
  * many other imporvents
* Mon Jul  2 2018 tchvatal@suse.com
- Drop dependency over devel python package, not needed
- Do not skip build on < 3.4 python, we do not ship that anywhere
  (last seen on 13.1)
* Sat Apr 14 2018 sebix+novell.com@sebix.at
- update to version 0.590:
  * New Features
  * experimental support for PEP 561
  * Incremental mode is on by default
  * Flags for always true/false
  * Add a per-module follow_imports_for_stubs options
  * Notable Bugs Fixed
  * Fix error message when assigning to read-only property (PR 4863 by Michael Lee, fixes issue 4756)
  * Respect --follow-imports=silent in --warn-unused-ignores (PR 4857, fixes issue 3949)
  * Don't produce spurious “unused type ignore” messages in incremental mode (PR 4841, fixes issue 2960)
  * Fix operator access on Type[...] (PR 4823, fixes issue 4789)
  * Remove incorrect override check on overloaded methods (PR 4810 by Michael Lee, fixes issue 4565)
  * Handle NotImplemented returned from __ne__ (PR 4770 by Peter Ludemann, fixes issue 4767)
  * Options in mypy.ini should be spelled with underscores, not hyphens (PR 4754 by Emil Hessman, fixes issue 4753)
  * Documentation Improvements
  * Add coroutines to cheat sheet (PR 4677 by Rob Day)
  * Add None return/strict-optional to common issues (PR 4594 by Viet Hung Nguyen)
  * Mention that SupportsInt and friends don't support arithmetic (PR 4781, fixes issue 4758)
  * Stubgen Improvements
  * Emit Any type annotations for unannotated arguments (PR 4774 by Matt Gilson, fixes issue 4766)
  * Fix stubgen --recursive to only generate stubs for requested submodules. (PR 4845 by Matt Gilson, fixes issue 4844)
  * Properly format Callables (PR 4650 by Evan Hubinger, fixes issue 4640)
* Fri Mar 23 2018 sebix+novell.com@sebix.at
- update to version 0.580:
  * Type check class decorators
  * Plugin for typechecking classes generated by attrs (Documentation)
  * Hooks into the semantic analyzer for plugins (PR 4328, PR 4397)
  * bugfixes and improved error messages
* Fri Mar  2 2018 sebix+novell.com@sebix.at
- update to version 0.570:
  * Add support for attrs_package
* Sat Dec 16 2017 sebix+novell.com@sebix.at
- update to version 0.560:
  * Iterable and Friends Are Now Protocols
  * Improved Error Messages
- include compiled docs in package
* Sat Nov 11 2017 sebix+novell.com@sebix.at
- fix build for distributions with python 3.4
* Fri Nov 10 2017 sebix+novell.com@sebix.at
- update to 0.550:
  * Running mypy now requires Python 3.4 or higher.
  However Python 3.3 is still valid for the target
  of the analysis (i.e. the `--python-version` flag).
  * Split `--disallow-any` flag into `separate boolean flags <disallow-any>`.
  * The `--old-html-report` flag was removed.
* Sat Oct 21 2017 sebix+novell.com@sebix.at
- update to 0.540
  * Switch to More Rapid Releases
  new mypy version roughly every 2-4 weeks
  * New Features
  * Allow assignments to multiple targets from union types (Ivan Levkivskyi, PR 4067)
  * Allow definitions of subscripted type aliases such as Item = Tuple[int, str] within functions (Ivan Levkivskyi, PR 4000)
  * Narrow type of optional left operand of in operator if the collection items aren’t optional (Ivan Levkivskyi, PR 4072)
  * Generate an error if <unknown> type would be inferred for a variable (PR 4112)
  * Notable Bugs Fixed
  * Fix errors not being reported for some modules with incremental mode by deleting cache file for a module if errors are found (Ivan Levkivskyi, PR 4045)
  * Fix incremental mode crash related to Type[...] types (Ivan Levkivskyi, PR 4038)
  * Fix crash related to tuple types (Ivan Levkivskyi, PR 4051)
  * Fix incorrect errors about __getattr__ methods (Ivan Levkivskyi, PR 4073)
  * Fixes to non-method attributes with callable types (Elazar Gershuni, PR 4016)
  * Fix function overloading based on Type[...] types (Ivan Levkivskyi, PR 4037)
  * Fix processing invalid overloaded function definitions (Elazar Gershuni, PR 4064)
  * Fix handling of disallow_any/disallow_untyped_defs combination in mypy config file (Jelle Zijlstra, PR 4076)
* Wed Aug  9 2017 sebix+novell.com@sebix.at
- fix shebang removal
* Thu Jul 27 2017 sebix+novell.com@sebix.at
- update to 0.521
  * Mypy Bugs Fixed
  * Fix crash on name collision for self attributes (Ivan Levkivskyi, PRs 3700 and 3719)
  * Fix bug in cache updates and improve cache logging (PR 3708)
  * Fix per-file strict Optional interaction with default-None args (PR 3686)
  * Fix crash in --quick mode when aliases are re-exported (Ivan Levkivskyi, PR 3740)
  * Fix crash on incompatible redefinition in named tuple (Ivan Levkivskyi, PR 3760)
  * Typeshed Bugs Fixed
  * Fix regressions in csv.DictReader (Thomas Grainger, PRs 1475 and 1478)
* Sat Jul 15 2017 sebix+novell.com@sebix.at
- upgrade to 0.520
  * Add :ref:`fine-grained control of Any types <disallow-any>`.
  * Add :ref:`typeddict`.
  * Other updates to :ref:`command-line`:
  * Add --no-implicit-optional.
  * Add --shadow-file.
  * Add --no-incremental.
* Thu Jul  6 2017 sebix+novell.com@sebix.at
- correct shebangs of typeshed libs
- fix build for older versions
* Thu Jul  6 2017 jengelh@inai.de
- Enhance description by some more text from the webpage.
* Tue Jun 27 2017 sebix+novell.com@sebix.at
- use python singlespec approach marking as uncompatible with python2
* Mon May  8 2017 sebix+novell.com@sebix.at
- first package
